@@ -1,4 +1,4 @@
-// Copyright (C) 2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2019-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -226,6 +226,7 @@ TEST_F(VendorOptsTest, vendorOptionsORO) {
     dis->addOption(clientid);
     // Set interface. It is required by the server to generate server id.
     dis->setIface("eth0");
+    dis->setIndex(ETH0_INDEX);
 
     // Pass it to the server and get an advertise
     Pkt4Ptr offer = srv.processDiscover(dis);
@@ -317,6 +318,7 @@ TEST_F(VendorOptsTest, vendorPersistentOptions) {
     dis->addOption(clientid);
     // Set interface. It is required by the server to generate server id.
     dis->setIface("eth0");
+    dis->setIndex(ETH0_INDEX);
 
     // Let's add a vendor-option (vendor-id=4491).
     OptionPtr vendor(new OptionVendor(Option::V4, 4491));
@@ -557,6 +559,7 @@ TEST_F(VendorOptsTest, option43LastResort) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a PRL option to the query
     OptionUint8ArrayPtr prl(new OptionUint8Array(Option::V4,
@@ -631,6 +634,7 @@ TEST_F(VendorOptsTest, option43BadRaw) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     // with not compatible (not parsable as suboptions) content
@@ -684,7 +688,7 @@ TEST_F(VendorOptsTest, option43FailRaw) {
     // The vendor-encapsulated-options has an incompatible data
     // so won't have the expected content. Here the processing
     // of suboptions tries to unpack the uitn32 foo suboption and
-    // raises an exception.
+    // raises an exception which is caught so the option stays unpacked.
     string config = "{ \"interfaces-config\": {"
         "    \"interfaces\": [ \"*\" ] }, "
         "\"subnet4\": [ "
@@ -721,6 +725,7 @@ TEST_F(VendorOptsTest, option43FailRaw) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     // with not compatible (not parsable as suboptions) content
@@ -742,7 +747,9 @@ TEST_F(VendorOptsTest, option43FailRaw) {
     query->addOption(prl);
 
     srv.classifyPacket(query);
-    EXPECT_THROW(srv.deferredUnpack(query), InvalidOptionValue);
+    EXPECT_NO_THROW(srv.deferredUnpack(query));
+    ASSERT_TRUE(query->getOption(vopt->getType()));
+    EXPECT_EQ(vopt, query->getOption(vopt->getType()));
 }
 
 // Verifies raw option 43 can be handled (global)
@@ -789,6 +796,7 @@ TEST_F(VendorOptsTest, option43RawGlobal) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     // with not compatible (not parsable as suboptions) content
@@ -881,6 +889,7 @@ TEST_F(VendorOptsTest, option43RawClass) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     // with not compatible (not parsable as suboptions) content
@@ -980,6 +989,7 @@ TEST_F(VendorOptsTest, option43Class) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     OptionBuffer buf;
@@ -1111,6 +1121,7 @@ TEST_F(VendorOptsTest, option43ClassPriority) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     OptionBuffer buf;
@@ -1248,6 +1259,7 @@ TEST_F(VendorOptsTest, option43Classes) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a vendor-encapsulated-options (code 43)
     OptionBuffer buf;
@@ -1321,7 +1333,7 @@ TEST_F(VendorOptsTest, clientOption43FailRaw) {
     // The vendor-encapsulated-options has an incompatible data
     // so won't have the expected content. Here the processing
     // of suboptions tries to unpack the uint32 foo suboption and
-    // raises an exception.
+    // raises an exception which is caught.
     string config = "{ \"interfaces-config\": {"
         "    \"interfaces\": [ \"*\" ] }, "
         "\"subnet4\": [ "
@@ -1346,9 +1358,9 @@ TEST_F(VendorOptsTest, clientOption43FailRaw) {
     client.addExtraOption(vopt);
 
     // Let's check whether the server is not able to process this packet
-    // and raises an exception so the response is empty.
+    // and raises an exception which is caught so the response is not empty.
     EXPECT_NO_THROW(client.doDiscover());
-    EXPECT_FALSE(client.getContext().response_);
+    EXPECT_TRUE(client.getContext().response_);
 }
 
 // Verifies raw option 43 sent by a client can be handled (global)
@@ -1592,6 +1604,7 @@ TEST_F(VendorOptsTest, vendorOpsSubOption0) {
     OptionPtr clientid = generateClientId();
     query->addOption(clientid);
     query->setIface("eth1");
+    query->setIndex(ETH1_INDEX);
 
     // Create and add a PRL option to the query
     OptionUint8ArrayPtr prl(new OptionUint8Array(Option::V4,
