@@ -37,6 +37,7 @@ using namespace isc::hooks;
 using namespace isc::stats;
 using namespace isc::util;
 using namespace std;
+namespace ph = std::placeholders;
 
 namespace {
 
@@ -662,7 +663,15 @@ ControlledDhcpv6Srv::commandStatusGetHandler(const string&,
         status->set("reload", Element::create(reload.total_seconds()));
     }
 
-    // todo: number of service threads.
+    if (MultiThreadingMgr::instance().getMode()) {
+        status->set("multi-threading-enabled", Element::create(true));
+        status->set("thread-pool-size", Element::create(static_cast<int32_t>(
+                        MultiThreadingMgr::instance().getThreadPoolSize())));
+        status->set("packet-queue-size", Element::create(static_cast<int32_t>(
+                        MultiThreadingMgr::instance().getPacketQueueSize())));
+    } else {
+        status->set("multi-threading-enabled", Element::create(false));
+    }
 
     return (createAnswer(0, status));
 }
@@ -759,7 +768,7 @@ ControlledDhcpv6Srv::processCommand(const string& command,
         return (isc::config::createAnswer(1, "Unrecognized command:"
                                           + command));
 
-    } catch (const Exception& ex) {
+    } catch (const isc::Exception& ex) {
         return (isc::config::createAnswer(1, "Error while processing command '"
                                           + command + "':" + ex.what() +
                                           ", params: '" + txt + "'"));
@@ -800,7 +809,7 @@ ControlledDhcpv6Srv::processConfig(isc::data::ConstElementPtr config) {
     // Re-open lease and host database with new parameters.
     try {
         DatabaseConnection::db_lost_callback =
-            boost::bind(&ControlledDhcpv6Srv::dbLostCallback, srv, _1);
+            std::bind(&ControlledDhcpv6Srv::dbLostCallback, srv, ph::_1);
         CfgDbAccessPtr cfg_db = CfgMgr::instance().getStagingCfg()->getCfgDbAccess();
         cfg_db->setAppendedParameters("universe=6");
         cfg_db->createManagers();
@@ -905,9 +914,9 @@ ControlledDhcpv6Srv::processConfig(isc::data::ConstElementPtr config) {
             boost::shared_ptr<unsigned> failure_count(new unsigned(0));
             TimerMgr::instance()->
                 registerTimer("Dhcp6CBFetchTimer",
-                              boost::bind(&ControlledDhcpv6Srv::cbFetchUpdates,
-                                          server_, CfgMgr::instance().getStagingCfg(),
-                                          failure_count),
+                              std::bind(&ControlledDhcpv6Srv::cbFetchUpdates,
+                                        server_, CfgMgr::instance().getStagingCfg(),
+                                        failure_count),
                               fetch_time,
                               asiolink::IntervalTimer::ONE_SHOT);
             TimerMgr::instance()->setup("Dhcp6CBFetchTimer");
@@ -992,80 +1001,80 @@ ControlledDhcpv6Srv::ControlledDhcpv6Srv(uint16_t server_port,
     // These are the commands always supported by the DHCPv6 server.
     // Please keep the list in alphabetic order.
     CommandMgr::instance().registerCommand("build-report",
-        boost::bind(&ControlledDhcpv6Srv::commandBuildReportHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandBuildReportHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-backend-pull",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigBackendPullHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigBackendPullHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-get",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigGetHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigGetHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-reload",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigReloadHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigReloadHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-test",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigTestHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigTestHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-write",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigWriteHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigWriteHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("dhcp-disable",
-        boost::bind(&ControlledDhcpv6Srv::commandDhcpDisableHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandDhcpDisableHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("dhcp-enable",
-        boost::bind(&ControlledDhcpv6Srv::commandDhcpEnableHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandDhcpEnableHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("leases-reclaim",
-        boost::bind(&ControlledDhcpv6Srv::commandLeasesReclaimHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandLeasesReclaimHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("server-tag-get",
-        boost::bind(&ControlledDhcpv6Srv::commandServerTagGetHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandServerTagGetHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("libreload",
-        boost::bind(&ControlledDhcpv6Srv::commandLibReloadHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandLibReloadHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("config-set",
-        boost::bind(&ControlledDhcpv6Srv::commandConfigSetHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandConfigSetHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("shutdown",
-        boost::bind(&ControlledDhcpv6Srv::commandShutdownHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandShutdownHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("status-get",
-        boost::bind(&ControlledDhcpv6Srv::commandStatusGetHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandStatusGetHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("version-get",
-        boost::bind(&ControlledDhcpv6Srv::commandVersionGetHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandVersionGetHandler, this, ph::_1, ph::_2));
 
     // Register statistic related commands
     CommandMgr::instance().registerCommand("statistic-get",
-        boost::bind(&StatsMgr::statisticGetHandler, _1, _2));
+        std::bind(&StatsMgr::statisticGetHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-get-all",
-        boost::bind(&StatsMgr::statisticGetAllHandler, _1, _2));
+        std::bind(&StatsMgr::statisticGetAllHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-reset",
-        boost::bind(&StatsMgr::statisticResetHandler, _1, _2));
+        std::bind(&StatsMgr::statisticResetHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-reset-all",
-        boost::bind(&StatsMgr::statisticResetAllHandler, _1, _2));
+        std::bind(&StatsMgr::statisticResetAllHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-remove",
-        boost::bind(&StatsMgr::statisticRemoveHandler, _1, _2));
+        std::bind(&StatsMgr::statisticRemoveHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-remove-all",
-        boost::bind(&StatsMgr::statisticRemoveAllHandler, _1, _2));
+        std::bind(&StatsMgr::statisticRemoveAllHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-sample-age-set",
-        boost::bind(&StatsMgr::statisticSetMaxSampleAgeHandler, _1, _2));
+        std::bind(&StatsMgr::statisticSetMaxSampleAgeHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-sample-age-set-all",
-        boost::bind(&ControlledDhcpv6Srv::commandStatisticSetMaxSampleAgeAllHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandStatisticSetMaxSampleAgeAllHandler, this, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-sample-count-set",
-        boost::bind(&StatsMgr::statisticSetMaxSampleCountHandler, _1, _2));
+        std::bind(&StatsMgr::statisticSetMaxSampleCountHandler, ph::_1, ph::_2));
 
     CommandMgr::instance().registerCommand("statistic-sample-count-set-all",
-        boost::bind(&ControlledDhcpv6Srv::commandStatisticSetMaxSampleCountAllHandler, this, _1, _2));
+        std::bind(&ControlledDhcpv6Srv::commandStatisticSetMaxSampleCountAllHandler, this, ph::_1, ph::_2));
 }
 
 void ControlledDhcpv6Srv::shutdownServer(int exit_value) {
@@ -1137,9 +1146,14 @@ ControlledDhcpv6Srv::reclaimExpiredLeases(const size_t max_leases,
                                           const uint16_t timeout,
                                           const bool remove_lease,
                                           const uint16_t max_unwarned_cycles) {
-    server_->alloc_engine_->reclaimExpiredLeases6(max_leases, timeout,
-                                                  remove_lease,
-                                                  max_unwarned_cycles);
+    try {
+        server_->alloc_engine_->reclaimExpiredLeases6(max_leases, timeout,
+                                                      remove_lease,
+                                                      max_unwarned_cycles);
+    } catch (const std::exception& ex) {
+        LOG_ERROR(dhcp6_logger, DHCP6_RECLAIM_EXPIRED_LEASES_FAIL)
+            .arg(ex.what());
+    }
     // We're using the ONE_SHOT timer so there is a need to re-schedule it.
     TimerMgr::instance()->setup(CfgExpiration::RECLAIM_EXPIRED_TIMER_NAME);
 }
@@ -1155,10 +1169,17 @@ void
 ControlledDhcpv6Srv::dbReconnect(ReconnectCtlPtr db_reconnect_ctl) {
     bool reopened = false;
 
-    // Re-open lease and host database with new parameters.
+    // We lost at least one of them. Reopen all of them (lease, host, and CB databases).
     try {
         CfgDbAccessPtr cfg_db = CfgMgr::instance().getCurrentCfg()->getCfgDbAccess();
         cfg_db->createManagers();
+
+        auto ctl_info = CfgMgr::instance().getCurrentCfg()->getConfigControlInfo();
+        if (ctl_info) {
+            auto srv_cfg = CfgMgr::instance().getCurrentCfg();
+            server_->getCBControl()->databaseConfigConnect(srv_cfg);
+        }
+
         reopened = true;
     } catch (const std::exception& ex) {
         LOG_ERROR(dhcp6_logger, DHCP6_DB_RECONNECT_ATTEMPT_FAILED).arg(ex.what());
@@ -1191,8 +1212,8 @@ ControlledDhcpv6Srv::dbReconnect(ReconnectCtlPtr db_reconnect_ctl) {
 
         if (!TimerMgr::instance()->isTimerRegistered("Dhcp6DbReconnectTimer")) {
             TimerMgr::instance()->registerTimer("Dhcp6DbReconnectTimer",
-                            boost::bind(&ControlledDhcpv6Srv::dbReconnect, this,
-                                        db_reconnect_ctl),
+                            std::bind(&ControlledDhcpv6Srv::dbReconnect, this,
+                                      db_reconnect_ctl),
                             db_reconnect_ctl->retryInterval(),
                             asiolink::IntervalTimer::ONE_SHOT);
         }
