@@ -51,6 +51,7 @@ using namespace isc::hooks;
 using namespace isc::stats;
 using namespace isc::test;
 using namespace isc::util;
+namespace ph = std::placeholders;
 
 namespace {
 
@@ -715,7 +716,8 @@ TEST_F(CtrlChannelDhcpv6SrvTest, configSet) {
         CfgMgr::instance().getCurrentCfg()->getCfgSubnets6()->getAll();
     EXPECT_EQ(1, subnets->size());
 
-    OptionDefinitionPtr def = LibDHCP::getRuntimeOptionDef("dhcp6", 163);
+    OptionDefinitionPtr def =
+        LibDHCP::getRuntimeOptionDef(DHCP6_OPTION_SPACE, 163);
     ASSERT_TRUE(def);
 
     // Create a config with malformed subnet that should fail to parse.
@@ -744,7 +746,7 @@ TEST_F(CtrlChannelDhcpv6SrvTest, configSet) {
     subnets = CfgMgr::instance().getCurrentCfg()->getCfgSubnets6()->getAll();
     EXPECT_EQ(1, subnets->size());
 
-    def = LibDHCP::getRuntimeOptionDef("dhcp6", 163);
+    def = LibDHCP::getRuntimeOptionDef(DHCP6_OPTION_SPACE, 163);
     ASSERT_TRUE(def);
 
     // Create a valid config with two subnets and no command channel.
@@ -1007,6 +1009,61 @@ TEST_F(CtrlChannelDhcpv6SrvTest, statusGet) {
     ASSERT_TRUE(found_reload);
     EXPECT_LE(found_reload->intValue(), 5);
     EXPECT_GE(found_reload->intValue(), 0);
+
+    auto found_multi_threading = arguments->get("multi-threading-enabled");
+    ASSERT_TRUE(found_multi_threading);
+    EXPECT_EQ(false, found_multi_threading->boolValue());
+
+    auto found_thread_count = arguments->get("thread-pool-size");
+    ASSERT_FALSE(found_thread_count);
+
+    auto found_queue_size = arguments->get("packet-queue-size");
+    ASSERT_FALSE(found_queue_size);
+
+    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingMgr::instance().setThreadPoolSize(4);
+    MultiThreadingMgr::instance().setPacketQueueSize(64);
+    sendUnixCommand("{ \"command\": \"status-get\" }", response_txt);
+    ASSERT_NO_THROW(response = Element::fromJSON(response_txt));
+    ASSERT_TRUE(response);
+    ASSERT_EQ(Element::map, response->getType());
+    EXPECT_EQ(2, response->size());
+    result = response->get("result");
+    ASSERT_TRUE(result);
+    ASSERT_EQ(Element::integer, result->getType());
+    EXPECT_EQ(0, result->intValue());
+    arguments = response->get("arguments");
+    ASSERT_EQ(Element::map, arguments->getType());
+
+    // The returned pid should be the pid of our process.
+    found_pid = arguments->get("pid");
+    ASSERT_TRUE(found_pid);
+    EXPECT_EQ(static_cast<int64_t>(getpid()), found_pid->intValue());
+
+    // It is hard to check the actual uptime (and reload) as it is based
+    // on current time. Let's just make sure it is within a reasonable
+    // range.
+    found_uptime = arguments->get("uptime");
+    ASSERT_TRUE(found_uptime);
+    EXPECT_LE(found_uptime->intValue(), 5);
+    EXPECT_GE(found_uptime->intValue(), 0);
+
+    found_reload = arguments->get("reload");
+    ASSERT_TRUE(found_reload);
+    EXPECT_LE(found_reload->intValue(), 5);
+    EXPECT_GE(found_reload->intValue(), 0);
+
+    found_multi_threading = arguments->get("multi-threading-enabled");
+    ASSERT_TRUE(found_multi_threading);
+    EXPECT_EQ(true, found_multi_threading->boolValue());
+
+    found_thread_count = arguments->get("thread-pool-size");
+    ASSERT_TRUE(found_thread_count);
+    EXPECT_EQ(found_thread_count->intValue(), 4);
+
+    found_queue_size = arguments->get("packet-queue-size");
+    ASSERT_TRUE(found_queue_size);
+    EXPECT_EQ(found_queue_size->intValue(), 64);
 }
 
 // This test verifies that the DHCP server handles server-tag-get command
@@ -1555,8 +1612,8 @@ TEST_F(CtrlChannelDhcpv6SrvTest, longCommand) {
 
     ASSERT_NO_THROW(
         CommandMgr::instance().registerCommand("foo",
-             boost::bind(&CtrlChannelDhcpv6SrvTest::longCommandHandler,
-                         command.str(), _1, _2));
+             std::bind(&CtrlChannelDhcpv6SrvTest::longCommandHandler,
+                       command.str(), ph::_1, ph::_2));
     );
 
     createUnixChannelServer();
@@ -1614,7 +1671,7 @@ TEST_F(CtrlChannelDhcpv6SrvTest, longResponse) {
     // of a desired size.
     ASSERT_NO_THROW(
         CommandMgr::instance().registerCommand("foo",
-             boost::bind(&CtrlChannelDhcpv6SrvTest::longResponseHandler, _1, _2));
+             std::bind(&CtrlChannelDhcpv6SrvTest::longResponseHandler, ph::_1, ph::_2));
     );
 
     createUnixChannelServer();
