@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -12,7 +12,6 @@
 #include <util/io_utilities.h>
 #include <util/range_utilities.h>
 #include <util/strutil.h>
-#include <boost/foreach.hpp>
 #include <ctime>
 #include <fstream>
 #include <stdlib.h>
@@ -167,9 +166,9 @@ DUIDFactory::createEN(const uint32_t enterprise_id,
             // Variable length identifier consists of random numbers. The generated
             // identifier is always 6 bytes long.
             ::srandom(time(NULL));
-            fillRandom(&duid_out[DUID_TYPE_LEN + ENTERPRISE_ID_LEN],
-                       &duid_out[DUID_TYPE_LEN + ENTERPRISE_ID_LEN +
-                                 DUID_EN_IDENTIFIER_LEN]);
+            fillRandom(duid_out.begin() + DUID_TYPE_LEN + ENTERPRISE_ID_LEN,
+                       duid_out.end());
+
         } else {
             // Append existing identifier.
             duid_out.insert(duid_out.end(), identifier_current.begin(),
@@ -244,10 +243,8 @@ DUIDFactory::createLL(const uint16_t htype,
 void
 DUIDFactory::createLinkLayerId(std::vector<uint8_t>& identifier,
                                uint16_t& htype) const {
-    const IfaceMgr::IfaceCollection& ifaces = IfaceMgr::instance().getIfaces();
-
     // Let's find suitable interface.
-    BOOST_FOREACH(IfacePtr iface, ifaces) {
+    for (IfacePtr iface : IfaceMgr::instance().getIfaces()) {
         // All the following checks could be merged into one multi-condition
         // statement, but let's keep them separated as perhaps one day
         // we will grow knobs to selectively turn them on or off. Also,
