@@ -722,6 +722,7 @@ Subnet4ConfigParser::parse(ConstElementPtr subnet) {
         HostReservationsListParser<HostReservationParser4> parser;
         parser.parse(subnet_->getID(), reservations, hosts);
         for (auto h = hosts.begin(); h != hosts.end(); ++h) {
+            validateResv(sn4ptr, *h);
             CfgMgr::instance().getStagingCfg()->getCfgHosts()->add(*h);
         }
     }
@@ -746,20 +747,35 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
     NetworkPtr network = boost::dynamic_pointer_cast<Network>(subnet4);
     parseCommon(params, network);
 
-    stringstream s;
-    s << addr << "/" << static_cast<int>(len) << " with params: ";
+    std::ostringstream output;
+    output << addr << "/" << static_cast<int>(len) << " with params: ";
+
+    bool has_renew = !subnet4->getT1().unspecified();
+    bool has_rebind = !subnet4->getT2().unspecified();
+    int64_t renew = -1;
+    int64_t rebind = -1;
+
     // t1 and t2 are optional may be not specified.
-    if (!subnet4->getT1().unspecified()) {
-        s << "t1=" << subnet4->getT1().get() << ", ";
+    if (has_renew) {
+        renew = subnet4->getT1().get();
+        output << "t1=" << renew << ", ";
     }
-    if (!subnet4->getT2().unspecified()) {
-        s << "t2=" << subnet4->getT2().get() << ", ";
-    }
-    if (!subnet4->getValid().unspecified()) {
-        s << "valid-lifetime=" << subnet4->getValid().get();
+    if (has_rebind) {
+        rebind = subnet4->getT2().get();
+        output << "t2=" << rebind << ", ";
     }
 
-    LOG_INFO(dhcpsrv_logger, DHCPSRV_CFGMGR_NEW_SUBNET4).arg(s.str());
+    if (has_renew && has_rebind && (renew > rebind)) {
+        isc_throw(DhcpConfigError, "the value of renew-timer" << " (" << renew
+                  << ") is greater than the value of rebind-timer" << " ("
+                  << rebind << ")");
+    }
+
+    if (!subnet4->getValid().unspecified()) {
+        output << "valid-lifetime=" << subnet4->getValid().get();
+    }
+
+    LOG_INFO(dhcpsrv_logger, DHCPSRV_CFGMGR_NEW_SUBNET4).arg(output.str());
 
     // Set the match-client-id value for the subnet.
     if (params->contains("match-client-id")) {
@@ -930,6 +946,16 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
     parseDdnsParams(params, network);
 }
 
+void
+Subnet4ConfigParser::validateResv(const Subnet4Ptr& subnet, ConstHostPtr host) {
+    const IOAddress& address = host->getIPv4Reservation();
+    if (!address.isV4Zero() && !subnet->inRange(address)) {
+        isc_throw(DhcpConfigError, "specified reservation '" << address
+                  << "' is not within the IPv4 subnet '"
+                  << subnet->toText() << "'");
+    }
+}
+
 //**************************** Subnets4ListConfigParser **********************
 
 Subnets4ListConfigParser::Subnets4ListConfigParser(bool check_iface)
@@ -1166,6 +1192,7 @@ Subnet6ConfigParser::parse(ConstElementPtr subnet) {
         HostReservationsListParser<HostReservationParser6> parser;
         parser.parse(subnet_->getID(), reservations, hosts);
         for (auto h = hosts.begin(); h != hosts.end(); ++h) {
+            validateResvs(sn6ptr, *h);
             CfgMgr::instance().getStagingCfg()->getCfgHosts()->add(*h);
         }
     }
@@ -1219,12 +1246,27 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
     std::ostringstream output;
     output << addr << "/" << static_cast<int>(len) << " with params: ";
     // t1 and t2 are optional may be not specified.
-    if (!subnet6->getT1().unspecified()) {
-        output << "t1=" << subnet6->getT1().get() << ", ";
+
+    bool has_renew = !subnet6->getT1().unspecified();
+    bool has_rebind = !subnet6->getT2().unspecified();
+    int64_t renew = -1;
+    int64_t rebind = -1;
+
+    if (has_renew) {
+        renew = subnet6->getT1().get();
+        output << "t1=" << renew << ", ";
     }
-    if (!subnet6->getT2().unspecified()) {
-        output << "t2=" << subnet6->getT2().get() << ", ";
+    if (has_rebind) {
+        rebind = subnet6->getT2().get();
+        output << "t2=" << rebind << ", ";
     }
+
+    if (has_renew && has_rebind && (renew > rebind)) {
+        isc_throw(DhcpConfigError, "the value of renew-timer" << " (" << renew
+                  << ") is greater than the value of rebind-timer" << " ("
+                  << rebind << ")");
+    }
+
     if (!subnet6->getPreferred().unspecified()) {
         output << "preferred-lifetime=" << subnet6->getPreferred().get() << ", ";
     }
@@ -1327,6 +1369,19 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
     parseDdnsParams(params, network);
 }
 
+void
+Subnet6ConfigParser::validateResvs(const Subnet6Ptr& subnet, ConstHostPtr host) {
+    IPv6ResrvRange range = host->getIPv6Reservations(IPv6Resrv::TYPE_NA);
+    for (auto it = range.first; it != range.second; ++it) {
+        const IOAddress& address = it->second.getPrefix();
+        if (!subnet->inRange(address)) {
+            isc_throw(DhcpConfigError, "specified reservation '" << address
+                      << "' is not within the IPv6 subnet '"
+                      << subnet->toText() << "'");
+        }
+    }
+}
+
 //**************************** Subnet6ListConfigParser ********************
 
 Subnets6ListConfigParser::Subnets6ListConfigParser(bool check_iface)
@@ -1525,5 +1580,5 @@ D2ClientConfigParser::setAllDefaults(isc::data::ConstElementPtr d2_config) {
     return (SimpleParser::setDefaults(mutable_d2, D2_CLIENT_CONFIG_DEFAULTS));
 }
 
-};  // namespace dhcp
-};  // namespace isc
+} // namespace dhcp
+} // namespace isc
