@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -33,6 +33,7 @@ using namespace isc::db;
 using namespace isc::dhcp;
 using namespace isc::dhcp::test;
 using namespace isc::asiolink;
+namespace ph = std::placeholders;
 
 namespace {
 
@@ -1109,7 +1110,7 @@ public:
     /// valid query.  Next it simulates connectivity lost by identifying and
     /// closing the socket connection to the host backend.  It then reissues
     /// the query and verifies that:
-    /// -# The Query throws  DbOperationError (rather than exiting)
+    /// -# The Query throws  DbConnectionUnusable (rather than exiting)
     /// -# The registered DbLostCallback was invoked
     void testDbLostCallback();
 #endif
@@ -1131,7 +1132,7 @@ HostMgrDbLostCallbackTest::testDbLostCallback() {
 
     // Set the connectivity lost callback.
     DatabaseConnection::db_lost_callback =
-        boost::bind(&HostMgrDbLostCallbackTest::db_lost_callback, this, _1);
+        std::bind(&HostMgrDbLostCallbackTest::db_lost_callback, this, ph::_1);
 
     // Find the most recently opened socket. Our SQL client's socket should
     // be the next one.
@@ -1154,9 +1155,9 @@ HostMgrDbLostCallbackTest::testDbLostCallback() {
     // Now close the sql socket out from under backend client
     ASSERT_FALSE(close(sql_socket)) << "failed to close socket";
 
-    // A query should fail with DbOperationError.
+    // A query should fail with DbConnectionUnusable.
     ASSERT_THROW(hosts = HostMgr::instance().getAll4(IOAddress("192.0.2.5")),
-                 DbOperationError);
+                 DbConnectionUnusable);
 
     // Our lost connectivity callback should have been invoked.
     EXPECT_TRUE(callback_called_);
