@@ -15,12 +15,13 @@
 #include <process/d_controller.h>
 #include <process/config_base.h>
 #include <kea_version.h>
-#include <boost/bind.hpp>
+#include <functional>
 #include <sstream>
 #include <unistd.h>
 
 using namespace isc::data;
 using namespace isc::config;
+namespace ph = std::placeholders;
 
 namespace isc {
 namespace process {
@@ -739,9 +740,9 @@ DControllerBase::initSignalHandling() {
 
     // Create our signal set.
     io_signal_set_.reset(new IOSignalSet(io_service_,
-                                         boost::bind(&DControllerBase::
-                                                     processSignal,
-                                                     this, _1)));
+                                         std::bind(&DControllerBase::
+                                                   processSignal,
+                                                   this, ph::_1)));
     // Register for the signals we wish to handle.
     io_signal_set_->add(SIGHUP);
     io_signal_set_->add(SIGINT);
