@@ -14,13 +14,13 @@
 #include <process/config_base.h>
 #include <util/filename.h>
 
-#include <boost/bind.hpp>
-
+#include <functional>
 #include <sstream>
 #include <fstream>
 #include <errno.h>
 
 using namespace isc::data;
+namespace ph = std::placeholders;
 
 /// @brief provides default implementation for basic daemon operations
 ///
@@ -63,7 +63,7 @@ void Daemon::shutdown() {
 
 void Daemon::handleSignal() {
     if (signal_set_ && signal_handler_) {
-        signal_set_->handleNext(boost::bind(signal_handler_, _1));
+        signal_set_->handleNext(std::bind(signal_handler_, ph::_1));
     }
 }
 
@@ -251,5 +251,5 @@ Daemon::writeConfigFile(const std::string& config_file,
     return (bytes);
 }
 
-};
-};
+}
+}
